@@ -20,17 +20,27 @@ add(
 add(
     'input',
     action='store',
+    nargs='+',
     type=str,
-    help='File to be converted',
+    help='File(s) to convert',
     default='',
 )
 add(
     '--iv', '-i',
     action='store',
     type=str,
-    help='AES decryption initialization vector. Used instead of voucher or key derivation.',
+    help='AES decryption initialization vector. '
+    'Used instead of voucher or key derivation.',
     default=None
 )
+add(
+    '--jobs', '-j',
+    action='store',
+    dest='thread_count',
+    type=int,
+    default=8,
+    help='the number of parallel threads to use'
+)
 add(
     '--key', '-k',
     action='store',
