@@ -60,13 +60,6 @@ def stderr(*args):
 
 class TinyTag(object):
     def __init__(self, filehandler, filesize, ignore_errors=False):
-        # This is required for compatibility between python2 and python3
-        # in python2 there is a difference between `str` and `unicode`
-        # whereas in python3 everything every string is `unicode` by default and
-        # the type `unicode` is deprecated
-        if type(filehandler).__name__ in ('str', 'unicode'):
-            raise Exception(
-                'Use `TinyTag.get(filepath)` instead of `TinyTag(filepath)`')
         self._filehandler = filehandler
         self._filename = None  # for debugging purposes
         self._default_encoding = None  # allow override for some file formats
